@@ -1,4 +1,8 @@
 import logging
+import string
+
+NAMES_ALLOWED_CHARS = string.ascii_letters + string.digits + " !@'+-.,/:;_$&*()%<=>?#[]{|}^~" + '"'
+NAMES_MAX_LENGTH = 4096
 
 GLOBAL_CONFIG_FILE = "/etc/tuned/tuned-main.conf"
 ACTIVE_PROFILE_FILE = "/etc/tuned/active_profile"
@@ -13,7 +17,8 @@ DBUS_INTERFACE = "com.redhat.tuned.control"
 DBUS_OBJECT = "/Tuned"
 DEFAULT_PROFILE = "balanced"
 DEFAULT_STORAGE_FILE = "/run/tuned/save.pickle"
-LOAD_DIRECTORIES = ["/usr/lib/tuned", "/etc/tuned"]
+USER_PROFILES_DIR = "/etc/tuned/profiles"
+SYSTEM_PROFILES_DIR = "/usr/lib/tuned/profiles"
 PERSISTENT_STORAGE_DIR = "/var/lib/tuned"
 PLUGIN_MAIN_UNIT_NAME = "main"
 # Magic section header because ConfigParser does not support "headerless" config
@@ -66,6 +71,9 @@ SYSTEMD_CPUAFFINITY_VAR = "CPUAffinity"
 # irqbalance plugin configuration
 IRQBALANCE_SYSCONFIG_FILE = "/etc/sysconfig/irqbalance"
 
+# acpi plugin configuration
+ACPI_DIR = "/sys/firmware/acpi"
+
 # built-in functions configuration
 SYSFS_CPUS_PATH = "/sys/devices/system/cpu"
 
@@ -73,6 +81,7 @@ SYSFS_CPUS_PATH = "/sys/devices/system/cpu"
 LOG_FILE_COUNT = 2
 LOG_FILE_MAXBYTES = 100*1000
 LOG_FILE = "/var/log/tuned/tuned.log"
+PPD_LOG_FILE = "/var/log/tuned/tuned-ppd.log"
 PID_FILE = "/run/tuned/tuned.pid"
 SYSTEM_RELEASE_FILE = "/etc/system-release-cpe"
 # prefix for functions plugins
@@ -87,6 +96,13 @@ ROLLBACK_FULL = 2
 PREFIX_PROFILE_FACTORY = "System"
 PREFIX_PROFILE_USER = "User"
 
+# PPD-to-tuned API translation daemon configuration
+PPD_NAMESPACE = "net.hadess.PowerProfiles"
+PPD_DBUS_BUS = PPD_NAMESPACE
+PPD_DBUS_OBJECT = "/net/hadess/PowerProfiles"
+PPD_DBUS_INTERFACE = PPD_DBUS_BUS
+PPD_CONFIG_FILE = "/etc/tuned/ppd.conf"
+
 # After adding new option to tuned-main.conf add here its name with CFG_ prefix
 # and eventually default value with CFG_DEF_ prefix (default is None)
 # and function for check with CFG_FUNC_ prefix
@@ -112,6 +128,7 @@ CFG_UNIX_SOCKET_PERMISIONS = "unix_socket_permissions"
 CFG_UNIX_SOCKET_CONNECTIONS_BACKLOG = "connections_backlog"
 CFG_CPU_EPP_FLAG = "hwp_epp"
 CFG_ROLLBACK = "rollback"
+CFG_PROFILE_DIRS = "profile_dirs"
 
 # no_daemon mode
 CFG_DEF_DAEMON = True
@@ -161,6 +178,8 @@ CFG_DEF_UNIX_SOCKET_CONNECTIONS_BACKLOG = "1024"
 CFG_FUNC_UNIX_SOCKET_CONNECTIONS_BACKLOG = "getint"
 # default rollback strategy
 CFG_DEF_ROLLBACK = "auto"
+# default profile directories
+CFG_DEF_PROFILE_DIRS = [SYSTEM_PROFILES_DIR, USER_PROFILES_DIR]
 
 PATH_CPU_DMA_LATENCY = "/dev/cpu_dma_latency"
 
@@ -202,3 +221,8 @@ CAPTURE_LOG_LEVELS = {
 		"console": LOG_LEVEL_CONSOLE,
 		"none": None,
 		}
+
+# number of retries when waiting for device initialization
+HOTPLUG_WAIT_FOR_DEV_INIT_RETRIES = 100
+# how long to wait for device initialization in seconds during retry
+HOTPLUG_WAIT_FOR_DEV_INIT_DELAY = 0.1
