@@ -80,7 +80,7 @@ class Plugin(object):
 			if key in effective or self._has_dynamic_options:
 				effective[key] = options[key]
 			else:
-				log.warn("Unknown option '%s' for plugin '%s'." % (key, self.__class__.__name__))
+				log.warning("Unknown option '%s' for plugin '%s'." % (key, self.__class__.__name__))
 		return effective
 
 	def _option_bool(self, value):
@@ -93,15 +93,16 @@ class Plugin(object):
 	# Interface for manipulation with instances of the plugin.
 	#
 
-	def create_instance(self, name, devices_expression, devices_udev_regex, script_pre, script_post, options):
+	def create_instance(self, name, priority, devices_expression, devices_udev_regex, script_pre, script_post, options):
 		"""Create new instance of the plugin and seize the devices."""
 		if name in self._instances:
 			raise Exception("Plugin instance with name '%s' already exists." % name)
 
 		effective_options = self._get_effective_options(options)
-		instance = self._instance_factory.create(self, name, devices_expression, devices_udev_regex, \
+		instance = self._instance_factory.create(self, name, priority, devices_expression, devices_udev_regex, \
 			script_pre, script_post, effective_options)
 		self._instances[name] = instance
+		self._instances = collections.OrderedDict(sorted(self._instances.items(), key=lambda x: x[1].priority))
 
 		return instance
 
@@ -171,7 +172,7 @@ class Plugin(object):
 		to_assign = self._get_matching_devices(instance, self._free_devices)
 		instance.active = len(to_assign) > 0
 		if not instance.active:
-			log.warn("instance %s: no matching devices available" % instance.name)
+			log.warning("instance %s: no matching devices available" % instance.name)
 		else:
 			name = instance.name
 			if instance.name != self.name:
@@ -212,16 +213,28 @@ class Plugin(object):
 	def _instance_post_static(self, instance, enabling):
 		pass
 
+	def _safe_script_path(self, path):
+		path = os.path.realpath(path)
+		profile_paths = self._global_cfg.get_list(consts.CFG_PROFILE_DIRS, consts.CFG_DEF_PROFILE_DIRS)
+		for p in profile_paths:
+			if path.startswith(p):
+				return True
+		return False
+
 	def _call_device_script(self, instance, script, op, devices, rollback = consts.ROLLBACK_SOFT):
 		if script is None:
 			return None
 		if len(devices) == 0:
-			log.warn("Instance '%s': no device to call script '%s' for." % (instance.name, script))
+			log.warning("Instance '%s': no device to call script '%s' for." % (instance.name, script))
 			return None
 		if not script.startswith("/"):
 			log.error("Relative paths cannot be used in script_pre or script_post. " \
 				+ "Use ${i:PROFILE_DIR}.")
 			return False
+		if not self._safe_script_path(script):
+			log.error("Paths outside of the profile directories cannot be used in the " \
+				+ "script_pre or script_post, ignoring script: '%s'" % script)
+			return False
 		dir_name = os.path.dirname(script)
 		ret = True
 		for dev in devices:
@@ -263,6 +276,7 @@ class Plugin(object):
 			self._call_device_script(instance, instance.script_post,
 					"apply", instance.assigned_devices)
 		if instance.has_dynamic_tuning and self._global_cfg.get(consts.CFG_DYNAMIC_TUNING, consts.CFG_DEF_DYNAMIC_TUNING):
+			self._instance_init_dynamic(instance)
 			self._run_for_each_device(instance, self._instance_apply_dynamic, instance.assigned_devices)
 		instance.processed_devices.update(instance.assigned_devices)
 		instance.assigned_devices.clear()
@@ -333,6 +347,9 @@ class Plugin(object):
 				instance.processed_devices)
 		self._cleanup_all_non_device_commands(instance)
 
+	def _instance_init_dynamic(self, instance):
+		pass
+
 	def _instance_apply_dynamic(self, instance, device):
 		for option in [opt for opt in self._options_used_by_dynamic if self._storage_get(instance, self._commands[opt], device) is None]:
 			self._check_and_save_value(instance, self._commands[option], device)
@@ -484,7 +501,7 @@ class Plugin(object):
 					else:
 						return None
 			except ValueError:
-				log.warn("cannot compare new value '%s' with current value '%s' by operator '%s', using '%s' directly as new value" % (val, current_value, op, new_value))
+				log.warning("cannot compare new value '%s' with current value '%s' by operator '%s', using '%s' directly as new value" % (val, current_value, op, new_value))
 		return new_value
 
 	def _get_current_value(self, command, device = None, ignore_missing=False):
@@ -506,7 +523,7 @@ class Plugin(object):
 		else:
 			new_value = self._check_and_save_value(instance, command, device, new_value)
 			if new_value is not None:
-				command["set"](new_value, device, sim = False)
+				command["set"](new_value, device, sim = False, remove = False)
 
 	def _execute_non_device_command(self, instance, command, new_value):
 		if command["custom"] is not None:
@@ -514,7 +531,7 @@ class Plugin(object):
 		else:
 			new_value = self._check_and_save_value(instance, command, None, new_value)
 			if new_value is not None:
-				command["set"](new_value, sim = False)
+				command["set"](new_value, sim = False, remove = False)
 
 	def _norm_value(self, value):
 		v = self._cmd.unquote(str(value))
@@ -576,7 +593,7 @@ class Plugin(object):
 		new_value = self._process_assignment_modifiers(new_value, current_value)
 		if new_value is None:
 			return None
-		new_value = command["set"](new_value, device, True)
+		new_value = command["set"](new_value, device, True, False)
 		return self._verify_value(command["name"], new_value, current_value, ignore_missing, device)
 
 	def _verify_non_device_command(self, instance, command, new_value, ignore_missing):
@@ -586,7 +603,7 @@ class Plugin(object):
 		new_value = self._process_assignment_modifiers(new_value, current_value)
 		if new_value is None:
 			return None
-		new_value = command["set"](new_value, True)
+		new_value = command["set"](new_value, True, False)
 		return self._verify_value(command["name"], new_value, current_value, ignore_missing)
 
 	def _cleanup_all_non_device_commands(self, instance):
@@ -594,19 +611,19 @@ class Plugin(object):
 			if (instance.options.get(command["name"], None) is not None) or (command["name"] in self._options_used_by_dynamic):
 				self._cleanup_non_device_command(instance, command)
 
-	def _cleanup_all_device_commands(self, instance, devices):
+	def _cleanup_all_device_commands(self, instance, devices, remove = False):
 		for command in reversed([command for command in list(self._commands.values()) if command["per_device"]]):
 			if (instance.options.get(command["name"], None) is not None) or (command["name"] in self._options_used_by_dynamic):
 				for device in devices:
-					self._cleanup_device_command(instance, command, device)
+					self._cleanup_device_command(instance, command, device, remove)
 
-	def _cleanup_device_command(self, instance, command, device):
+	def _cleanup_device_command(self, instance, command, device, remove = False):
 		if command["custom"] is not None:
 			command["custom"](False, None, device, False, False)
 		else:
 			old_value = self._storage_get(instance, command, device)
 			if old_value is not None:
-				command["set"](old_value, device, sim = False)
+				command["set"](old_value, device, sim = False, remove = remove)
 			self._storage_unset(instance, command, device)
 
 	def _cleanup_non_device_command(self, instance, command):
@@ -615,5 +632,5 @@ class Plugin(object):
 		else:
 			old_value = self._storage_get(instance, command)
 			if old_value is not None:
-				command["set"](old_value, sim = False)
+				command["set"](old_value, sim = False, remove = False)
 			self._storage_unset(instance, command)
