@@ -251,7 +251,7 @@ class BootloaderPlugin(base.Plugin):
 			return None
 		splited = out.split()
 		if len(splited) < 2 or splited[0] != "State:":
-			log.warn("Exceptional format of rpm-ostree status result:\n%s" % out)
+			log.warning("Exceptional format of rpm-ostree status result:\n%s" % out)
 			return None
 		return splited[1]
 
@@ -304,6 +304,10 @@ class BootloaderPlugin(base.Plugin):
 			kargs.setdefault(k, []).extend(val)
 			appended[k] = val
 
+		if append_params == delete_params:
+			log.info("skipping rpm-ostree kargs - append == deleting (%s)" % append_params)
+			return kargs, appended, deleted
+
 		log.info("rpm-ostree kargs - appending: '%s'; deleting: '%s'" % (append_params, delete_params))
 		(rc, _, err) = self._cmd.execute(['rpm-ostree', 'kargs'] +
 										 ['--append=%s' % v for v in append_params] +
@@ -324,7 +328,7 @@ class BootloaderPlugin(base.Plugin):
 			elif key in effective:
 				effective[key] = options[key]
 			else:
-				log.warn("Unknown option '%s' for plugin '%s'." % (key, self.__class__.__name__))
+				log.warning("Unknown option '%s' for plugin '%s'." % (key, self.__class__.__name__))
 		cmdline = ""
 		for key in cmdline_keys:
 			val = options[key]
@@ -373,7 +377,7 @@ class BootloaderPlugin(base.Plugin):
 			log.info("cannot find grub.cfg to patch")
 			return
 		for f in self._grub2_cfg_file_names:
-			self._cmd.add_modify_option_in_file(f, {"set\s+" + consts.GRUB2_TUNED_VAR : "", "set\s+" + consts.GRUB2_TUNED_INITRD_VAR : ""}, add = False)
+			self._cmd.add_modify_option_in_file(f, {r"set\s+" + consts.GRUB2_TUNED_VAR : "", r"set\s+" + consts.GRUB2_TUNED_INITRD_VAR : ""}, add = False)
 		if self._initrd_dst_img_val is not None:
 			log.info("removing initrd image '%s'" % self._initrd_dst_img_val)
 			self._cmd.unlink(self._initrd_dst_img_val)
@@ -391,8 +395,8 @@ class BootloaderPlugin(base.Plugin):
 		self._rpm_ostree_kargs(append=self._options_to_dict(deleted), delete=self._options_to_dict(appended))
 		self._patch_bootcmdline({consts.BOOT_CMDLINE_TUNED_VAR: "", consts.BOOT_CMDLINE_KARGS_DELETED_VAR: ""})
 
-	def _instance_unapply_static(self, instance, full_rollback = False):
-		if full_rollback and not self._skip_grub_config_val:
+	def _instance_unapply_static(self, instance, rollback = consts.ROLLBACK_SOFT):
+		if rollback == consts.ROLLBACK_FULL and not self._skip_grub_config_val:
 			if self._rpm_ostree:
 				log.info("removing rpm-ostree tuning previously added by Tuned")
 				self._remove_rpm_ostree_tuning()
@@ -403,9 +407,9 @@ class BootloaderPlugin(base.Plugin):
 
 	def _grub2_cfg_unpatch(self, grub2_cfg):
 		log.debug("unpatching grub.cfg")
-		cfg = re.sub(r"^\s*set\s+" + consts.GRUB2_TUNED_VAR + "\s*=.*\n", "", grub2_cfg, flags = re.MULTILINE)
+		cfg = re.sub(r"^\s*set\s+" + consts.GRUB2_TUNED_VAR + "\\s*=.*\n", "", grub2_cfg, flags = re.MULTILINE)
 		grub2_cfg = re.sub(r" *\$" + consts.GRUB2_TUNED_VAR, "", cfg, flags = re.MULTILINE)
-		cfg = re.sub(r"^\s*set\s+" + consts.GRUB2_TUNED_INITRD_VAR + "\s*=.*\n", "", grub2_cfg, flags = re.MULTILINE)
+		cfg = re.sub(r"^\s*set\s+" + consts.GRUB2_TUNED_INITRD_VAR + "\\s*=.*\n", "", grub2_cfg, flags = re.MULTILINE)
 		grub2_cfg = re.sub(r" *\$" + consts.GRUB2_TUNED_INITRD_VAR, "", cfg, flags = re.MULTILINE)
 		cfg = re.sub(consts.GRUB2_TEMPLATE_HEADER_BEGIN + r"\n", "", grub2_cfg, flags = re.MULTILINE)
 		return re.sub(consts.GRUB2_TEMPLATE_HEADER_END + r"\n+", "", cfg, flags = re.MULTILINE)
@@ -480,7 +484,7 @@ class BootloaderPlugin(base.Plugin):
 			grub2_cfg_new = grub2_cfg
 			patch_initial = False
 			for opt in d:
-				(grub2_cfg_new, nsubs) = re.subn(r"\b(set\s+" + opt + "\s*=).*$", r"\1" + "\"" + self._cmd.escape(d[opt]) + "\"", grub2_cfg_new, flags = re.MULTILINE)
+				(grub2_cfg_new, nsubs) = re.subn(r"\b(set\s+" + opt + r"\s*=).*$", r"\1" + "\"" + self._cmd.escape(d[opt]) + "\"", grub2_cfg_new, flags = re.MULTILINE)
 				if nsubs < 1 or re.search(r"\$" + opt, grub2_cfg, flags = re.MULTILINE) is None:
 					patch_initial = True
 
@@ -520,7 +524,7 @@ class BootloaderPlugin(base.Plugin):
 		l = ["%s=%s" % (str(option), str(value)) for option, value in d.items()]
 		(rc, out) = self._cmd.execute(["grub2-editenv", "-", "set"] + l)
 		if rc != 0:
-			log.warn("cannot update grubenv: '%s'" % out)
+			log.warning("cannot update grubenv: '%s'" % out)
 			return False
 		return True
 
@@ -531,7 +535,7 @@ class BootloaderPlugin(base.Plugin):
 		log.debug("running kernel update hook '%s' to patch BLS entries" % consts.KERNEL_UPDATE_HOOK_FILE)
 		(rc, out) = self._cmd.execute([consts.KERNEL_UPDATE_HOOK_FILE, "add"], env = {"KERNEL_INSTALL_MACHINE_ID" : machine_id})
 		if rc != 0:
-			log.warn("cannot patch BLS entries: '%s'" % out)
+			log.warning("cannot patch BLS entries: '%s'" % out)
 			return False
 		return True
 
@@ -552,10 +556,10 @@ class BootloaderPlugin(base.Plugin):
 
 	def _install_initrd(self, img):
 		if self._rpm_ostree:
-			log.warn("Detected rpm-ostree which doesn't support initrd overlays.")
+			log.warning("Detected rpm-ostree which doesn't support initrd overlays.")
 			return False
 		if self._check_petitboot():
-			log.warn("Detected Petitboot which doesn't support initrd overlays. The initrd overlay will be ignored by bootloader.")
+			log.warning("Detected Petitboot which doesn't support initrd overlays. The initrd overlay will be ignored by bootloader.")
 		log.info("installing initrd image as '%s'" % self._initrd_dst_img_val)
 		img_name = os.path.basename(self._initrd_dst_img_val)
 		if not self._cmd.copy(img, self._initrd_dst_img_val):
@@ -687,9 +691,9 @@ class BootloaderPlugin(base.Plugin):
 	def _instance_post_static(self, instance, enabling):
 		if enabling and self._skip_grub_config_val:
 			if len(self._initrd_val) > 0:
-				log.warn("requested changes to initrd will not be applied!")
+				log.warning("requested changes to initrd will not be applied!")
 			if len(self._cmdline_val) > 0:
-				log.warn("requested changes to cmdline will not be applied!")
+				log.warning("requested changes to cmdline will not be applied!")
 			# ensure that the desired cmdline is always written to BOOT_CMDLINE_FILE (/etc/tuned/bootcmdline)
 			self._patch_bootcmdline({consts.BOOT_CMDLINE_TUNED_VAR : self._cmdline_val, consts.BOOT_CMDLINE_INITRD_ADD_VAR : self._initrd_val})
 		elif enabling and self.update_grub2_cfg:
