@@ -8,7 +8,23 @@ log = tuned.logs.get()
 
 class EeePCSHEPlugin(base.Plugin):
 	"""
-	Plugin for tuning FSB (front side bus) speed on Asus EEE PCs with SHE (Super Hybrid Engine) support.
+	`eeepc_she`::
+	
+	Dynamically sets the front-side bus (FSB) speed according to the
+	CPU load. This feature can be found on some netbooks and is also
+	known as the Asus Super Hybrid Engine. If the CPU load is lower or
+	equal to the value specified by the [option]`load_threshold_powersave`
+	option, the plug-in sets the FSB speed to the value specified by the
+	[option]`she_powersave` option. If the CPU load is higher or
+	equal to the value specified by the [option]`load_threshold_normal`
+	option, it sets the FSB speed to the value specified by the
+	[option]`she_normal` option. Static tuning is not supported and the
+	plug-in is transparently disabled if the hardware support for this
+	feature is not detected.
+	
+	NOTE: For details about the FSB frequencies and corresponding values, see
+	link:https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-platform-eeepc-laptop[the kernel documentation].
+	The provided defaults should work for most users.
 	"""
 
 	def __init__(self, *args, **kwargs):
@@ -33,13 +49,17 @@ class EeePCSHEPlugin(base.Plugin):
 		instance._has_static_tuning = False
 		instance._has_dynamic_tuning = True
 		instance._she_mode = None
-		instance._load_monitor = self._monitors_repository.create("load", None)
+		instance._load_monitor = None
 
 	def _instance_cleanup(self, instance):
 		if instance._load_monitor is not None:
 			self._monitors_repository.delete(instance._load_monitor)
 			instance._load_monitor = None
 
+	def _instance_init_dynamic(self, instance):
+		super(EeePCSHEPlugin, self)._instance_init_dynamic(instance)
+		instance._load_monitor = self._monitors_repository.create("load", None)
+
 	def _instance_update_dynamic(self, instance, device):
 		load = instance._load_monitor.get_load()["system"]
 		if load <= instance.options["load_threshold_powersave"]:
