@@ -11,7 +11,13 @@ cmd = commands()
 
 class MountsPlugin(base.Plugin):
 	"""
-	Plugin for tuning options of mount-points.
+	`mounts`::
+	
+	Enables or disables barriers for mounts according to the value of the
+	[option]`disable_barriers` option. The [option]`disable_barriers`
+	option has an optional value `force` which disables barriers even
+	on mountpoints with write back caches. Note that only extended file
+	systems (ext) are supported by this plug-in.
 	"""
 
 	@classmethod
