@@ -1,4 +1,5 @@
 import os
+import errno
 from . import base
 from .decorators import *
 import tuned.logs
@@ -9,7 +10,27 @@ log = tuned.logs.get()
 
 class SelinuxPlugin(base.Plugin):
 	"""
-	Plugin for tuning SELinux options.
+	`selinux`::
+	
+	Plug-in for tuning SELinux options.
+	+
+	SELinux decisions, such as allowing or denying access, are
+	cached. This cache is known as the Access Vector Cache (AVC). When
+	using these cached decisions, SELinux policy rules need to be checked
+	less, which increases performance. The [option]`avc_cache_threshold`
+	option allows adjusting the maximum number of AVC entries.
+	+
+	NOTE: Prior to changing the default value, evaluate the system
+	performance with care. Increasing the value could potentially
+	decrease the performance by making AVC slow.
+	+
+	.Increase the AVC cache threshold for hosts with containers.
+	====
+	----
+	[selinux]
+	avc_cache_threshold=8192
+	----
+	====
 	"""
 
 	@classmethod
@@ -43,13 +64,14 @@ class SelinuxPlugin(base.Plugin):
 		pass
 
 	@command_set("avc_cache_threshold")
-	def _set_avc_cache_threshold(self, value, sim):
+	def _set_avc_cache_threshold(self, value, sim, remove):
 		if value is None:
 			return None
 		threshold = int(value)
 		if threshold >= 0:
 			if not sim:
-				self._cmd.write_to_file(self._cache_threshold_path, threshold)
+				self._cmd.write_to_file(self._cache_threshold_path, threshold, \
+					no_error = [errno.ENOENT] if remove else False)
 			return threshold
 		else:
 			return None
