@@ -46,7 +46,7 @@ class Functions():
 		sl = re.split(r'(?<!\\):', self._str[_from:self._cnt])
 		if sl[0] != "${f":
 			return
-		sl = [str(v).replace("\:", ":") for v in sl]
+		sl = [str(v).replace(r"\:", ":") for v in sl]
 		if not re.match(r'\w+$', sl[1]):
 			log.error("invalid function name '%s'" % sl[1])
 			return
@@ -56,6 +56,7 @@ class Functions():
 			log.error("function '%s' not implemented" % sl[1])
 			return
 		s = f.execute(sl[2:])
+		log.debug("${f:%s} expands to: '%s'" % (":".join(sl[1:]), s))
 		if s is None:
 			return
 		self._sub(_from, self._cnt, s)
@@ -80,7 +81,7 @@ class Functions():
 				self._esc = False
 			self._cnt += 1
 		if len(self._stack):
-			log.error("invalid varialbe syntax, non pair '{' in: '%s'" % s)
+			log.error("invalid variable syntax, non pair '{' in: '%s'" % s)
 		return self._str
 
 	def expand(self, s):
