@@ -73,14 +73,15 @@ class Manager(object):
 				log.debug("skipping instance '%s', uname does not match" % instance_name)
 				continue
 
-			instance_info.options.setdefault("priority", self._def_instance_priority)
-			instance_info.options["priority"] = int(instance_info.options["priority"])
+			if instance_info.priority is None:
+				instance_info.priority = int(self._def_instance_priority)
+			else:
+				instance_info.priority = int(instance_info.priority)
 			instance_info_list.append(instance_info)
 
-		instance_info_list.sort(key=lambda x: x.options["priority"])
+		instance_info_list.sort(key=lambda x: x.priority)
 		plugins_by_name = collections.OrderedDict()
 		for instance_info in instance_info_list:
-			instance_info.options.pop("priority")
 			plugins_by_name[instance_info.type] = None
 
 		for plugin_name, none in list(plugins_by_name.items()):
@@ -102,7 +103,8 @@ class Manager(object):
 			if plugin is None:
 				continue
 			log.debug("creating '%s' (%s)" % (instance_info.name, instance_info.type))
-			new_instance = plugin.create_instance(instance_info.name, instance_info.devices, instance_info.devices_udev_regex, \
+			new_instance = plugin.create_instance(instance_info.name, instance_info.priority, \
+				instance_info.devices, instance_info.devices_udev_regex, \
 				instance_info.script_pre, instance_info.script_post, instance_info.options)
 			instances.append(new_instance)
 		for instance in instances:
@@ -133,7 +135,7 @@ class Manager(object):
 		for plugin in self._plugins:
 			log.debug("cleaning plugin '%s'" % plugin.name)
 			self._try_call("destroy_all", None, plugin.cleanup)
-
+		self._plugins_repository.plugins.clear()
 		del self._plugins[:]
 		del self._instances[:]
 
@@ -161,16 +163,16 @@ class Manager(object):
 			self._try_call("update_tuning", None,
 					instance.update_tuning)
 
-	# full_rollback is a helper telling plugins whether soft or full roll
-	# back is needed, e.g. for bootloader plugin we need e.g grub.cfg
+	# rollback parameter is a helper telling plugins whether soft or full
+	# rollback is needed, e.g. for bootloader plugin we need grub.cfg
 	# tuning to persist across reboots and restarts of the daemon, so in
-	# this case the full_rollback is usually set to False,  but we also
-	# need to clean it all up when TuneD is disabled or the profile is
-	# changed. In this case the full_rollback is set to True. In practice
-	# it means to remove all temporal or helper files, unpatch third
-	# party config files, etc.
-	def stop_tuning(self, full_rollback = False):
+	# this case the rollback is usually set to consts.ROLLBACK_SOFT,
+	# but we also need to clean it all up when TuneD is disabled or the
+	# profile is changed. In this case the rollback is set to
+	# consts.ROLLBACK_FULL. In practice it means to remove all temporal
+	# or helper files, unpatch third party config files, etc.
+	def stop_tuning(self, rollback = consts.ROLLBACK_SOFT):
 		self._hardware_inventory.stop_processing_events()
 		for instance in reversed(self._instances):
 			self._try_call("stop_tuning", None,
-					instance.unapply_tuning, full_rollback)
+					instance.unapply_tuning, rollback)
