@@ -1,12 +1,11 @@
 import errno
+import hashlib
 import tuned.logs
 import copy
 import os
 import shutil
 import tuned.consts as consts
-from configobj import ConfigObj, ConfigObjError
 import re
-import procfs
 from subprocess import *
 from tuned.exceptions import TunedException
 
@@ -15,7 +14,6 @@ log = tuned.logs.get()
 class commands:
 
 	def __init__(self, logging = True):
-		self._environment = None
 		self._logging = logging
 
 	def _error(self, msg):
@@ -31,7 +29,7 @@ class commands:
 		return {"Y":"1", "YES":"1", "T":"1", "TRUE":"1", "N":"0", "NO":"0", "F":"0", "FALSE":"0"}.get(v, value)
 
 	def remove_ws(self, s):
-		return re.sub('\s+', ' ', s).strip()
+		return re.sub(r'\s+', ' ', str(s)).strip()
 
 	def unquote(self, v):
 		return re.sub("^\"(.*)\"$", r"\1", v)
@@ -62,7 +60,7 @@ class commands:
 	def re_lookup_compile(self, d):
 		if d is None:
 			return None
-		return re.compile("(%s)" % ")|(".join(d.keys()))
+		return re.compile("(%s)" % ")|(".join(list(d.keys())))
 
 	# Do multiple regex replaces in 's' according to lookup table described by
 	# dictionary 'd', e.g.: d = {"re1": "replace1", "re2": "replace2", ...}
@@ -76,7 +74,7 @@ class commands:
 				return s
 		if r is None:
 			r = self.re_lookup_compile(d)
-		return r.sub(lambda mo: d.values()[mo.lastindex - 1], s, flags)
+		return r.sub(lambda mo: list(d.values())[mo.lastindex - 1], s, flags)
 
 	# Do regex lookup on 's' according to lookup table described by
 	# dictionary 'd' and return corresponding value from the dictionary,
@@ -89,10 +87,22 @@ class commands:
 			r = self.re_lookup_compile(d)
 		mo = r.search(s)
 		if mo:
-			return d.values()[mo.lastindex - 1]
+			return list(d.values())[mo.lastindex - 1]
 		return None
 
-	def write_to_file(self, f, data, makedir = False, no_error = False):
+	def write_to_file(self, f, data, makedir = False, no_error = False, ignore_same = False):
+		"""Write data to a file.
+
+		Parameters:
+		f -- filename where to write
+		data -- data to write
+		makedir -- if True and the path doesn't exist, it will be created
+		no_error -- if True errors are silenced, it can be also list of ignored errnos
+		ignore_same -- if True and the write would not change the file, it is skipped
+
+		Return:
+		bool -- True on success
+		"""
 		self._debug("Writing to file: '%s' < '%s'" % (f, data))
 		if makedir:
 			d = os.path.dirname(f)
@@ -101,22 +111,26 @@ class commands:
 		try:
 			if makedir:
 				os.makedirs(d)
+			if ignore_same and self.read_file(f, no_error=True).strip() == str(data):
+				self._debug("Skipping the write to file '%s', the content would not change" % f)
+				return True
 			fd = open(f, "w")
 			fd.write(str(data))
 			fd.close()
 			rc = True
-		except (OSError,IOError) as e:
+		except (OSError, IOError) as e:
 			rc = False
-			if not no_error:
-				self._error("Writing to file '%s' error: '%s'" % (f, e))
+			if isinstance(no_error, bool) and not no_error or \
+				isinstance(no_error, list) and e.errno not in no_error:
+					self._error("Writing to file '%s' error: '%s'" % (f, e))
 		return rc
 
 	def read_file(self, f, err_ret = "", no_error = False):
 		old_value = err_ret
 		try:
-			f = open(f, "r")
-			old_value = f.read()
-			f.close()
+			fd = open(f, "r")
+			old_value = fd.read()
+			fd.close()
 		except (OSError,IOError) as e:
 			if not no_error:
 				self._error("Error when reading file '%s': '%s'" % (f, e))
@@ -194,24 +208,42 @@ class commands:
 						data += "\n"
 					data += "%s=\"%s\"\n" % (o, v)
 			else:
-				data = re.sub(r"\b(" + o + r"\s*=).*$", r"\1" + "\"" + v + "\"", data, flags = re.MULTILINE)
+				data = re.sub(r"\b(" + o + r"\s*=).*$", r"\1" + "\"" + self.escape(v) + "\"", data, flags = re.MULTILINE)
 
 		return self.write_to_file(f, data)
 
+	# calcualates md5sum of file 'f'
+	def md5sum(self, f):
+		data = self.read_file(f)
+		return hashlib.md5(str(data).encode("utf-8")).hexdigest()
+
+	# calcualates sha256sum of file 'f'
+	def sha256sum(self, f):
+		data = self.read_file(f)
+		return hashlib.sha256(str(data).encode("utf-8")).hexdigest()
+
+	# returns machine ID or empty string "" in case of error
+	def get_machine_id(self, no_error = True):
+		return self.read_file(consts.MACHINE_ID_FILE, no_error).strip()
+
 	# "no_errors" can be list of return codes not treated as errors, if 0 is in no_errors, it means any error
 	# returns (retcode, out), where retcode is exit code of the executed process or -errno if
 	# OSError or IOError exception happened
-	def execute(self, args, shell = False, cwd = None, no_errors = [], return_err = False):
+	def execute(self, args, shell = False, cwd = None, env = {}, no_errors = [], return_err = False):
 		retcode = 0
-		if self._environment is None:
-			self._environment = os.environ.copy()
-			self._environment["LC_ALL"] = "C"
+		_environment = os.environ.copy()
+		_environment["LC_ALL"] = "C"
+		_environment.update(env)
 
 		self._debug("Executing %s." % str(args))
 		out = ""
 		err_msg = None
 		try:
-			proc = Popen(args, stdout = PIPE, stderr = PIPE, env = self._environment, shell = shell, cwd = cwd, close_fds = True)
+			proc = Popen(args, stdout = PIPE, stderr = PIPE, \
+					env = _environment, \
+					shell = shell, cwd = cwd, \
+					close_fds = True, \
+					universal_newlines = True)
 			out, err = proc.communicate()
 
 			retcode = proc.returncode
@@ -219,13 +251,13 @@ class commands:
 				err_out = err[:-1]
 				if len(err_out) == 0:
 					err_out = out[:-1]
-				err_msg = "Executing %s error: %s" % (args[0], err_out)
+				err_msg = "Executing '%s' error: %s" % (' '.join(args), err_out)
 				if not return_err:
 					self._error(err_msg)
 		except (OSError, IOError) as e:
 			retcode = -e.errno if e.errno is not None else -1
 			if not abs(retcode) in no_errors and not 0 in no_errors:
-				err_msg = "Executing %s error: %s" % (args[0], e)
+				err_msg = "Executing '%s' error: %s" % (' '.join(args), e)
 				if not return_err:
 					self._error(err_msg)
 		if return_err:
@@ -255,17 +287,21 @@ class commands:
 		if mask is None:
 			return None
 		mask = str(mask).replace(",", "")
-		cpu = 0
-		cpus = []
 		try:
 			m = int(mask, 16)
 		except ValueError:
 			log.error("invalid hexadecimal mask '%s'" % str(mask))
 			return []
-		while m > 0:
-			if m & 1:
+		return self.bitmask2cpulist(m)
+
+	# Converts an integer bitmask to a list of cpus (e.g. [0,3,4])
+	def bitmask2cpulist(self, mask):
+		cpu = 0
+		cpus = []
+		while mask > 0:
+			if mask & 1:
 				cpus.append(cpu)
-			m >>= 1
+			mask >>= 1
 			cpu += 1
 		return cpus
 
@@ -275,14 +311,18 @@ class commands:
 	# to be separated by ",,", e.g.: 0-3, 0xf,, 6. It also supports negation
 	# cpus by specifying "^" or "!", e.g.: 0-5, ^3, will output the list as
 	# "0,1,2,4,5" (excluding 3). Note: negation supports only cpu numbers.
-	def cpulist_unpack(self, l):
+	# If "strip_chars" is not None and l is not list, we try strip characters.
+	# It should be string with list of chars that is send to string.strip method
+	# Default is english single and double quotes ("') rhbz#1891036
+	def cpulist_unpack(self, l, strip_chars='\'"'):
 		rl = []
 		if l is None:
 			return l
-		if type(l) is list:
-			ll = l
-		else:
-			ll = str(l).split(",")
+		ll = l
+		if type(ll) is not list:
+			if strip_chars is not None:
+				ll = str(ll).strip(strip_chars)
+			ll = str(ll).split(",")
 		ll2 = []
 		negation_list = []
 		hexmask = False
@@ -302,7 +342,18 @@ class commands:
 					hexmask = True
 					hv = sv
 				elif sv and (sv[0] == "^" or sv[0] == "!"):
-					negation_list.append(int(sv[1:]))
+					nl = sv[1:].split("-")
+					try:
+						if (len(nl) > 1):
+							negation_list += list(range(
+								int(nl[0]),
+								int(nl[1]) + 1
+								)
+							)
+						else:
+							negation_list.append(int(sv[1:]))
+					except ValueError:
+						return []
 				else:
 					if len(sv) > 0:
 						ll2.append(sv)
@@ -315,7 +366,7 @@ class commands:
 			else:
 				try:
 					if len(vl) > 1:
-						rl += range(int(vl[0]), int(vl[1]) + 1)
+						rl += list(range(int(vl[0]), int(vl[1]) + 1))
 					else:
 						rl.append(int(vl[0]))
 				except ValueError:
@@ -355,19 +406,17 @@ class commands:
 	# Inverts CPU list (i.e. makes its complement)
 	def cpulist_invert(self, l):
 		cpus = self.cpulist_unpack(l)
-		present = self.cpulist_unpack(self.read_file("/sys/devices/system/cpu/present"))
-		return list(set(present) - set(cpus))
+		online = self.cpulist_unpack(self.read_file("/sys/devices/system/cpu/online"))
+		return list(set(online) - set(cpus))
 
 	# Converts CPU list to hexadecimal CPU mask
 	def cpulist2hex(self, l):
 		if l is None:
 			return None
-		m = 0
 		ul = self.cpulist_unpack(l)
 		if ul is None:
 			return None
-		for v in ul:
-			m |= pow(2, v)
+		m = self.cpulist2bitmask(ul)
 		s = "%x" % m
 		ls = len(s)
 		if ls % 8 != 0:
@@ -375,73 +424,34 @@ class commands:
 		s = s.zfill(ls)
 		return ",".join(s[i:i + 8] for i in range(0, len(s), 8))
 
-	def process_recommend_file(self, fname):
-		matching_profile = None
-		try:
-			if not os.path.isfile(fname):
-				return None
-			config = ConfigObj(fname, list_values = False, interpolation = False)
-			for section in config.keys():
-				match = True
-				for option in config[section].keys():
-					value = config[section][option]
-					if value == "":
-						value = r"^$"
-					if option == "virt":
-						if not re.match(value, self.execute("virt-what")[1], re.S):
-							match = False
-					elif option == "system":
-						if not re.match(value, self.read_file(consts.SYSTEM_RELEASE_FILE), re.S):
-							match = False
-					elif option[0] == "/":
-						if not os.path.exists(option) or not re.match(value, self.read_file(option), re.S):
-							match = False
-					elif option[0:7] == "process":
-						ps = procfs.pidstats()
-						ps.reload_threads()
-						if len(ps.find_by_regex(re.compile(value))) == 0:
-							match = False
-				if match:
-					# remove the ",.*" suffix
-					r = re.compile(r",[^,]*$")
-					matching_profile = r.sub("", section)
-					break
-		except (IOError, OSError, ConfigObjError) as e:
-			log.error("error processing '%s', %s" % (fname, e))
-		return matching_profile
+	def cpulist2bitmask(self, l):
+		m = 0
+		for v in l:
+			m |= pow(2, v)
+		return m
 
-	def recommend_profile(self, hardcoded = False):
-		profile = consts.DEFAULT_PROFILE
-		if hardcoded:
-			return profile
-		matching = self.process_recommend_file(consts.RECOMMEND_CONF_FILE)
-		if matching is not None:
-			return matching
-		files = {}
-		for directory in consts.RECOMMEND_DIRECTORIES:
-			contents = []
-			try:
-				contents = os.listdir(directory)
-			except OSError as e:
-				if e.errno != errno.ENOENT:
-					log.error("error accessing %s: %s" % (directory, e))
-			for name in contents:
-				path = os.path.join(directory, name)
-				files[name] = path
-		for name in sorted(files.keys()):
-			path = files[name]
-			matching = self.process_recommend_file(path)
-			if matching is not None:
-				return matching
-		return profile
+	def cpulist2string(self, l, prefix = ""):
+		return ",".join((prefix + str(v)) for v in l)
+
+	# Converts string s consisting of "dev1,dev2,dev3,..." to list ["dev1", "dev2, "dev3", ...],
+	# whitespaces are ignored, cpu lists are supported with the prefix "cpulist:", e.g.
+	# "cpulist:0-2,4" is converted to ["cpu0", "cpu1", "cpu2", "cpu4"]. If device name starts
+	# with "cpulist:" write it as "cpulist:cpulist:". Escape commas in name with the "\,".
+	def devstr2devs(self, s):
+		if s[0:8].lower() == "cpulist:":
+			s = s[8:]
+			if s[0:8].lower() != "cpulist:":
+				return [("cpu" + str(v)) for v in self.cpulist_unpack(s)]
+		l = re.split(r"\s*(?<!\\),\s*", s)
+		return [str(v).replace(r"\,", ",") for v in l]
 
 	# Do not make balancing on patched Python 2 interpreter (rhbz#1028122).
-	# It means less CPU usage on patchet interpreter. On non-patched interpreter
+	# It means less CPU usage on patched interpreter. On non-patched interpreter
 	# it is not allowed to sleep longer than 50 ms.
 	def wait(self, terminate, time):
 		try:
 			return terminate.wait(time, False)
-		except:
+		except TypeError as e:
 			return terminate.wait(time)
 
 	def get_size(self, s):
@@ -507,3 +517,38 @@ class commands:
 				f.write(mode + "\n")
 		except (OSError,IOError) as e:
 			raise TunedException("Failed to save profile mode: %s" % e.strerror)
+
+	def get_post_loaded_profile(self):
+		profile_name = ""
+		try:
+			with open(consts.POST_LOADED_PROFILE_FILE, "r") as f:
+				profile_name = f.read().strip()
+		except IOError as e:
+			if e.errno != errno.ENOENT:
+				raise TunedException("Failed to read the active post-loaded profile: %s" % e)
+		except (OSError, EOFError) as e:
+			raise TunedException("Failed to read the active post-loaded profile: %s" % e)
+		if profile_name == "":
+			profile_name = None
+		return profile_name
+
+	def save_post_loaded_profile(self, profile_name):
+		try:
+			with open(consts.POST_LOADED_PROFILE_FILE, "w") as f:
+				if profile_name is not None:
+					f.write(profile_name + "\n")
+		except (OSError,IOError) as e:
+			raise TunedException("Failed to save the active post-loaded profile: %s" % e.strerror)
+
+	# Translates characters in 'text' from 'source_chars' to 'dest_chars'
+	def tr(self, text, source_chars, dest_chars):
+		try:
+			trans = str.maketrans(source_chars, dest_chars)
+		except AttributeError:
+			import string
+			trans = string.maketrans(source_chars, dest_chars)
+		return text.translate(trans)
+
+	# Checks if name contains only valid characters and has valid length or is empty string or None
+	def is_valid_name(self, name):
+		return not name or (all(c in consts.NAMES_ALLOWED_CHARS for c in name) and len(name) <= consts.NAMES_MAX_LENGTH)
